# Dimethyl methylphosphonate, C3H9O3P

## Other names

- DMMP
- Methylphosphonic acid dimethyl ester
- dimethoxymethyl phosphine oxide
- Dimethyl methanephosphonate
- Dimethyl methyl phosphonate
- Fran TF 2000
- Fyron DMMP
- Metaran
- NSC 62240
- O,O-dimethyl methylphosphonate
- Reoflam DMMP

## External links

- Dimethyl methylphosphonate - Wikipedia
- Dimethyl methylphosphonate - NIST Chemistry WebBook